==> qthello_0.7.tar.gz: qthello-0.7/src/qthello_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CentralWidget</name>
    <message>
        <location filename="centralwidget.cpp" line="103"/>
        <source>Error!!
Unable to start the game server: %1.</source>
        <translation>Ошибка!!
Невозможо запустить сервер: %1.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="179"/>
        <source>Warning!
Wait answer from client.</source>
        <translation>Внимание!
Ожидание ответа от клиента.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="182"/>
        <source>Warning!
Client is paused.</source>
        <translation>Внимание!!
Клиент приостановлен.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="185"/>
        <source>Warning!
Server is paused.</source>
        <translation>Внимание!!
Сервер приостановлен.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="189"/>
        <source>Warning!
Wait answer from server.</source>
        <translation>Внимание!
Ожидание ответа от сервера.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="197"/>
        <source>Warning!
It&apos;s White player turn now.</source>
        <translation>Внимание!!
Ход белых.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="202"/>
        <source>Warning!
It&apos;s Black player turn now.</source>
        <translation>Внимание!!
Ход черных.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="216"/>
        <source>White</source>
        <translation>Белые</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="216"/>
        <source>Black</source>
        <translation>Черные</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="218"/>
        <source>%1 can&apos;t move. %2 turn.</source>
        <translation>%1 не могут ходить. %2 ходят.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="253"/>
        <source>Warning!
The host was not found.</source>
        <translation>Внимание!
Хост не найден.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="256"/>
        <source>Warning!
The connection was refused by the peer.</source>
        <translation>Внимание!
Соединение отброшено противополжной стороной.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="259"/>
        <source>The following error occurred: %1.</source>
        <translation>Возникла ошибка: %1.</translation>
    </message>
</context>
<context>
    <name>ClientDialog</name>
    <message>
        <location filename="clientdialog.cpp" line="18"/>
        <source>Waiting black player (server)</source>
        <translation>Ожидание черного игрока (сервера)</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="20"/>
        <source>Enter IP and port of server:</source>
        <translation>Введите IP и пор сервера:</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="24"/>
        <source>IP:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="29"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="38"/>
        <source>C&amp;onnect</source>
        <translation>&amp;Соединить</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="42"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
</context>
<context>
    <name>InfoPanel</name>
    <message>
        <location filename="infopanel.cpp" line="38"/>
        <source>Black turn</source>
        <translation>Черные ходят</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="52"/>
        <source>White</source>
        <translation>Белые</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="52"/>
        <source>Black</source>
        <translation>Черные</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="54"/>
        <source>%1 turn</source>
        <translation>%1 ходят</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="17"/>
        <source>Qthello</source>
        <translation>Qthello</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="38"/>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="39"/>
        <source>&amp;New game</source>
        <translation>&amp;Новая игра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="44"/>
        <source>E&amp;xit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="48"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="49"/>
        <source>&amp;About...</source>
        <translation>&amp;О программе...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="61"/>
        <source>Game over!
 White player %1; Black player %2.</source>
        <translation>Игра окончена!
Белые %1; Черные %2.</translation>
    </message>
    <message>
        <source>White</source>
        <translation type="obsolete">Белые</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="obsolete">Черные</translation>
    </message>
    <message>
        <source>%1 can&apos;t move. %2 turn.</source>
        <translation type="obsolete">%1 не могут ходить. %2 ходят.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="73"/>
        <source>About Qthello</source>
        <translation>Про Qthello</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="73"/>
        <source>Othello/Reversi game

General programming - (c) 2010 Vadim Khohlov &lt;xvadima@ukr.net&gt;

Images - GPE-Othello project (c) 2007 Joseph J. McCarthy &lt;mccarthy@granular.che.pitt.edu&gt;

AI Engine - KReversi project (c) 1997-2000, Mario Weilguni
(c) 2004-2006, Inge Wallin
(c) 2006, Dmitry Suzdalev</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ModePanel</name>
    <message>
        <location filename="modepanel.cpp" line="15"/>
        <source>Mode: </source>
        <translation>Режим:</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="17"/>
        <source>AI level: </source>
        <translation>Уровень ИИ:</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="21"/>
        <source>Human vs human</source>
        <translation>Чел. vs чел.</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="22"/>
        <source>Human vs computer</source>
        <translation>Чел. vs комп.</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="23"/>
        <source>Computer vs human</source>
        <translation>Комп. vs чел.</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="24"/>
        <source>Net (server)</source>
        <translation>Net (сервер)</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="25"/>
        <source>Net (client)</source>
        <translation>Net (клиент)</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="37"/>
        <source>Expert</source>
        <translation>Эксперт</translation>
    </message>
    <message>
        <source>Very easy</source>
        <translation type="obsolete">Очень простой</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="31"/>
        <source>Easy</source>
        <translation>Простой</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="32"/>
        <source>Medium</source>
        <translation>Средний</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="33"/>
        <source>Hard</source>
        <translation>Тяжелый</translation>
    </message>
</context>
<context>
    <name>ServerDialog</name>
    <message>
        <location filename="serverdialog.cpp" line="24"/>
        <source>Waiting white player (client)</source>
        <translation>Ожидание белого игрока (клиента)</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="26"/>
        <source>The server is running on:</source>
        <translation>Сервер запущен на:</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="30"/>
        <source>IP:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="50"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="52"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="64"/>
        <source>&amp;New game</source>
        <translation>&amp;Новая игра</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="68"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
</context>
</TS>

==> qthello_0.7.5.orig.tar.gz: qthello-0.7.5.orig/src/qthello_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CentralWidget</name>
    <message>
        <location filename="centralwidget.cpp" line="121"/>
        <source>Error!!
Unable to start the game server: %1.</source>
        <translation>Ошибка!!
Невозможо запустить сервер: %1.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="197"/>
        <source>Warning!
Wait answer from client.</source>
        <translation>Внимание!
Ожидание ответа от клиента.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="200"/>
        <source>Warning!
Client is paused.</source>
        <translation>Внимание!!
Клиент приостановлен.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="203"/>
        <source>Warning!
Server is paused.</source>
        <translation>Внимание!!
Сервер приостановлен.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="207"/>
        <source>Warning!
Wait answer from server.</source>
        <translation>Внимание!
Ожидание ответа от сервера.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="215"/>
        <source>Warning!
It&apos;s White player turn now.</source>
        <translation>Внимание!!
Ход белых.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="220"/>
        <source>Warning!
It&apos;s Black player turn now.</source>
        <translation>Внимание!!
Ход черных.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="234"/>
        <source>White</source>
        <translation>Белые</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="234"/>
        <source>Black</source>
        <translation>Черные</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="236"/>
        <source>%1 can&apos;t move. %2 turn.</source>
        <translation>%1 не могут ходить. %2 ходят.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="271"/>
        <source>Warning!
The host was not found.</source>
        <translation>Внимание!
Хост не найден.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="274"/>
        <source>Warning!
The connection was refused by the peer.</source>
        <translation>Внимание!
Соединение отброшено противополжной стороной.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="277"/>
        <source>The following error occurred: %1.</source>
        <translation>Возникла ошибка: %1.</translation>
    </message>
</context>
<context>
    <name>ClientDialog</name>
    <message>
        <location filename="clientdialog.cpp" line="18"/>
        <source>Waiting black player (server)</source>
        <translation>Ожидание черного игрока (сервера)</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="20"/>
        <source>Enter IP and port of server:</source>
        <translation>Введите IP и пор сервера:</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="24"/>
        <source>IP:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="29"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="38"/>
        <source>C&amp;onnect</source>
        <translation>&amp;Соединить</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="42"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
</context>
<context>
    <name>InfoPanel</name>
    <message>
        <location filename="infopanel.cpp" line="38"/>
        <source>Black turn</source>
        <translation>Черные ходят</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="52"/>
        <source>White</source>
        <translation>Белые</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="52"/>
        <source>Black</source>
        <translation>Черные</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="54"/>
        <source>%1 turn</source>
        <translation>%1 ходят</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="20"/>
        <source>Qthello</source>
        <translation>Qthello</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="41"/>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="42"/>
        <source>&amp;New game</source>
        <translation>&amp;Новая игра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="47"/>
        <source>E&amp;xit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="51"/>
        <source>&amp;Options</source>
        <translation>&amp;Параметры</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="52"/>
        <source>&amp;Options...</source>
        <translation>&amp;Параметры...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="55"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="56"/>
        <source>&amp;About...</source>
        <translation>&amp;О программе...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="68"/>
        <source>Game over!
 White player %1; Black player %2.</source>
        <translation>Игра окончена!
Белые %1; Черные %2.</translation>
    </message>
    <message>
        <source>White</source>
        <translation type="obsolete">Белые</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="obsolete">Черные</translation>
    </message>
    <message>
        <source>%1 can&apos;t move. %2 turn.</source>
        <translation type="obsolete">%1 не могут ходить. %2 ходят.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="80"/>
        <source>About Qthello</source>
        <translation>Про Qthello</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="80"/>
        <source>Othello/Reversi game

General programming - (c) 2010 Vadim Khohlov &lt;xvadima@ukr.net&gt;

Images - GPE-Othello project (c) 2007 Joseph J. McCarthy &lt;mccarthy@granular.che.pitt.edu&gt;

AI Engine - KReversi project (c) 1997-2000, Mario Weilguni
(c) 2004-2006, Inge Wallin
(c) 2006, Dmitry Suzdalev</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ModePanel</name>
    <message>
        <location filename="modepanel.cpp" line="15"/>
        <source>Mode: </source>
        <translation>Режим:</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="17"/>
        <source>AI level: </source>
        <translation>Уровень ИИ:</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="21"/>
        <source>Human vs human</source>
        <translation>Чел. vs чел.</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="22"/>
        <source>Human vs computer</source>
        <translation>Чел. vs комп.</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="23"/>
        <source>Computer vs human</source>
        <translation>Комп. vs чел.</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="24"/>
        <source>Net (server)</source>
        <translation>Net (сервер)</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="25"/>
        <source>Net (client)</source>
        <translation>Net (клиент)</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="33"/>
        <source>Expert</source>
        <translation>Эксперт</translation>
    </message>
    <message>
        <source>Very easy</source>
        <translation type="obsolete">Очень простой</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="30"/>
        <source>Easy</source>
        <translation>Простой</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="31"/>
        <source>Medium</source>
        <translation>Средний</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="32"/>
        <source>Hard</source>
        <translation>Тяжелый</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.cpp" line="17"/>
        <source>Animation speed:</source>
        <translation>Скорость анимации:</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="20"/>
        <source>No animation</source>
        <translation>Без анимации</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="21"/>
        <source>Slow</source>
        <translation>Медленно</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="22"/>
        <source>Medium</source>
        <translation>Средне</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="23"/>
        <source>Fast</source>
        <translation>Быстро</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="27"/>
        <source>&amp;Save mode on exit</source>
        <translation>&amp;Сохраять режим при выходе</translation>
    </message>
</context>
<context>
    <name>ServerDialog</name>
    <message>
        <location filename="serverdialog.cpp" line="24"/>
        <source>Waiting white player (client)</source>
        <translation>Ожидание белого игрока (клиента)</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="26"/>
        <source>The server is running on:</source>
        <translation>Сервер запущен на:</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="30"/>
        <source>IP:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="50"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="52"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="64"/>
        <source>&amp;New game</source>
        <translation>&amp;Новая игра</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="68"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
</context>
</TS>
